package
Version:
v0.0.0-...-ae6897b
Opens a new window with list of versions in this module.
Published: Jun 25, 2021
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type AppConfig struct {
AppName string `yaml:"appName"`
AppMode string `yaml:"appMode"`
AppPort int `yaml:"appPort"`
HttpAllowCrossDomain bool `yaml:"httpAllowCrossDomain"`
}
AppConfig 应用启动配置文件
Source Files
¶
Click to show internal directories.
Click to hide internal directories.